@@ -35,13 +35,13 @@ class InteractionExtractor:
             self.node_additional_attribute_list = self.additional_attributes.columns.values.tolist()
             self.node_additional_attribute_list.remove(extractor.additional_node_attributes_join)
 
-    async def extract(self):
+    async def extract(self, items_per_page):
         post_extractor = PostExtractor(self.extractor)
-        await post_extractor.extract()
+        await post_extractor.extract(items_per_page)
         self.feeds = post_extractor.nodes
 
-        #user_summary = self.build_user_summary()
-        #self.nodes.nodes = user_summary
+        user_summary = self.build_user_summary()
+        self.nodes.nodes = user_summary
 
         self.build_net()
 
@@ -49,8 +49,7 @@ class InteractionExtractor:
             self.build_ranking(net_type='directed')
             self.build_ranking(net_type='undirected')
 
-        #self.nodes.nodes = user_summary
-        self.nodes.nodes = pd.DataFrame()
+        self.nodes.nodes = user_summary
 
     @staticmethod
     def convert_to_undirected(g_directed):
